@@ -50,7 +50,7 @@ sub template {
       URL => $config->{_default}->{url},
       ROOT => $config->{_default}->{root},
       STATIC => $config->{_default}->{static},
-      IMGURL => $config->{_default}->{imgurl},
+      IMGURL => $config->{_default}->{imageurl},
       AUTHOR => $config->{_default}->{author},
       EMAIL => $config->{_default}->{email},
       FloorTITLE => $config->{$floor}->{title},
@@ -58,7 +58,7 @@ sub template {
       FloorURL => $config->{$floor}->{url},
       FloorROOT => $config->{$floor}->{root},
       FloorSTATIC => $config->{$floor}->{static},
-      FloorIMGURL => $config->{$floor}->{imgurl},
+      FloorIMGURL => $config->{$floor}->{imageurl},
       FloorAUTHOR => $config->{$floor}->{author},
       FloorEMAIL => $config->{$floor}->{email},
       PageTITLE => "$allentries->{$utid}->{title} - $config->{$floor}->{title}",
